==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
export let WebSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderDescriptionMetadata.a == null) {
                WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
            }
            if (a.k(WebSliderDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSliderDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebSliderBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Slider");
            a.item("__tagNameWC", "String:igc-slider");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "Number:double");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("InputRef", "EventRef::input");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebSliderDescriptionMetadata.b(a);
            a.ad("WebSlider", () => new WebSliderDescription());
            a.ac("WebSlider", WebSliderDescriptionMetadata.a);
        }
    }
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebSliderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebNumberEventArgsDescriptionMetadata } from "./WebNumberEventArgsDescriptionMetadata";
import { WebSliderBaseDescriptionMetadata } from "./WebSliderBaseDescriptionMetadata";
import { WebSliderDescription } from "./WebSliderDescription";
/**
 * @hidden
 */
export let WebSliderDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderDescriptionMetadata.a == null) {
                WebSliderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderDescriptionMetadata.c(WebSliderDescriptionMetadata.a);
            }
            if (a.k(WebSliderDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSliderDescriptionMetadata.a);
            WebNumberEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            WebSliderBaseDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:Slider");
            a.item("__tagNameWC", "String:igc-slider");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Value", "Number:double");
            a.item("DefaultValue", "Unknown");
            a.item("Name", "String");
            a.item("Invalid", "Boolean");
            a.item("InputRef", "EventRef::input");
            a.item("ChangeRef", "EventRef::change");
        }
        static d(a) {
            WebSliderDescriptionMetadata.b(a);
            a.ae("WebSlider", () => new WebSliderDescription());
            a.ad("WebSlider", WebSliderDescriptionMetadata.a);
        }
    }
    WebSliderDescriptionMetadata.$t = markType(WebSliderDescriptionMetadata, 'WebSliderDescriptionMetadata');
    WebSliderDescriptionMetadata.a = null;
    return WebSliderDescriptionMetadata;
})();
